@@ -30,23 +30,25 @@ import (
 )
 
 var (
-	debug            bool
-	mtu              int
-	endpoints        arrayFlags
-	vpnkitSocket     string
-	qemuSocket       string
-	bessSocket       string
-	stdioSocket      string
-	vfkitSocket      string
-	forwardSocket    arrayFlags
-	forwardDest      arrayFlags
-	forwardUser      arrayFlags
-	forwardIdentify  arrayFlags
-	sshPort          int
-	pidFile          string
-	exitCode         int
-	logFile          string
-	servicesEndpoint string
+	debug             bool
+	mtu               int
+	endpoints         arrayFlags
+	vpnkitSocket      string
+	qemuSocket        string
+	bessSocket        string
+	stdioSocket       string
+	vfkitSocket       string
+	forwardSocket     arrayFlags
+	forwardDest       arrayFlags
+	forwardUser       arrayFlags
+	forwardIdentify   arrayFlags
+	sshPort           int
+	pidFile           string
+	pcapFile          string
+	exitCode          int
+	logFile           string
+	servicesEndpoint  string
+	ec2MetadataAccess bool
 )
 
 const (
@@ -62,6 +64,7 @@ func main() {
 	version.AddFlag()
 	flag.Var(&endpoints, "listen", "control endpoint")
 	flag.BoolVar(&debug, "debug", false, "Print debug info")
+	flag.StringVar(&pcapFile, "pcap", "", "Capture network traffic to a pcap file")
 	flag.IntVar(&mtu, "mtu", 1500, "Set the MTU")
 	flag.IntVar(&sshPort, "ssh-port", 2222, "Port to access the guest virtual machine. Must be between 1024 and 65535")
 	flag.StringVar(&vpnkitSocket, "listen-vpnkit", "", "VPNKit socket to be used by Hyperkit")
@@ -76,6 +79,7 @@ func main() {
 	flag.StringVar(&pidFile, "pid-file", "", "Generate a file with the PID in it")
 	flag.StringVar(&logFile, "log-file", "", "Output log messages (logrus) to a given file path")
 	flag.StringVar(&servicesEndpoint, "services", "", "Exposes the same HTTP API as the --listen flag, without the /connect endpoint")
+	flag.BoolVar(&ec2MetadataAccess, "ec2-metadata-access", false, "Permits access to EC2 Metadata Service (TCP only)")
 	flag.Parse()
 
 	if version.ShowVersion() {
@@ -215,7 +219,7 @@ func main() {
 
 	config := types.Configuration{
 		Debug:             debug,
-		CaptureFile:       captureFile(),
+		CaptureFile:       pcapFile,
 		MTU:               mtu,
 		Subnet:            "192.168.127.0/24",
 		GatewayIP:         gatewayIP,
@@ -260,7 +264,8 @@ func main() {
 		VpnKitUUIDMacAddresses: map[string]string{
 			"c3d68012-0208-11ea-9fd7-f2189899ab08": "5a:94:ef:e4:0c:ee",
 		},
-		Protocol: protocol,
+		Protocol:          protocol,
+		Ec2MetadataAccess: ec2MetadataAccess,
 	}
 
 	groupErrs.Go(func() error {
@@ -305,13 +310,6 @@ func (i *arrayFlags) Set(value string) error {
 	return nil
 }
 
-func captureFile() string {
-	if !debug {
-		return ""
-	}
-	return "capture.pcap"
-}
-
 func run(ctx context.Context, g *errgroup.Group, configuration *types.Configuration, endpoints []string, servicesEndpoint string) error {
 	vn, err := virtualnetwork.New(configuration)
 	if err != nil {
@@ -447,7 +445,8 @@ func run(ctx context.Context, g *errgroup.Group, configuration *types.Configurat
 			if err := conn.Close(); err != nil {
 				log.Errorf("error closing %s: %q", vfkitSocket, err)
 			}
-			return os.Remove(vfkitSocket)
+			vfkitSocketURI, _ := url.Parse(vfkitSocket)
+			return os.Remove(vfkitSocketURI.Path)
 		})
 
 		g.Go(func() error {
@@ -571,9 +570,7 @@ func searchDomains() []string {
 		searchPrefix := "search "
 		for sc.Scan() {
 			if strings.HasPrefix(sc.Text(), searchPrefix) {
-				searchDomains := strings.Split(strings.TrimPrefix(sc.Text(), searchPrefix), " ")
-				log.Debugf("Using search domains: %v", searchDomains)
-				return searchDomains
+				return parseSearchString(sc.Text(), searchPrefix)
 			}
 		}
 		if err := sc.Err(); err != nil {
@@ -583,3 +580,29 @@ func searchDomains() []string {
 	}
 	return nil
 }
+
+// Parse and sanitize search list
+// macOS has limitation on number of domains (6) and general string length (256 characters)
+// since glibc 2.26 Linux has no limitation on 'search' field
+func parseSearchString(text, searchPrefix string) []string {
+	// macOS allow only 265 characters in search list
+	if runtime.GOOS == "darwin" && len(text) > 256 {
+		log.Errorf("Search domains list is too long, it should not exceed 256 chars on macOS: %d", len(text))
+		text = text[:256]
+		lastSpace := strings.LastIndex(text, " ")
+		if lastSpace != -1 {
+			text = text[:lastSpace]
+		}
+	}
+
+	searchDomains := strings.Split(strings.TrimPrefix(text, searchPrefix), " ")
+	log.Debugf("Using search domains: %v", searchDomains)
+
+	// macOS allow only 6 domains in search list
+	if runtime.GOOS == "darwin" && len(searchDomains) > 6 {
+		log.Errorf("Search domains list is too long, it should not exceed 6 domains on macOS: %d", len(searchDomains))
+		searchDomains = searchDomains[:6]
+	}
+
+	return searchDomains
+}
