@@ -16,20 +16,22 @@ import (
 	"sync"
 
 	"github.com/containers/gvisor-tap-vsock/pkg/sshclient"
+	"github.com/containers/gvisor-tap-vsock/pkg/tcpproxy"
 	"github.com/containers/gvisor-tap-vsock/pkg/types"
 	log "github.com/sirupsen/logrus"
 	"gvisor.dev/gvisor/pkg/tcpip"
 	"gvisor.dev/gvisor/pkg/tcpip/adapters/gonet"
 	"gvisor.dev/gvisor/pkg/tcpip/network/ipv4"
 	"gvisor.dev/gvisor/pkg/tcpip/stack"
-	"inet.af/tcpproxy"
 )
 
+type ProxyKey string
+
 type PortsForwarder struct {
 	stack *stack.Stack
 
 	proxiesLock sync.Mutex
-	proxies     map[string]proxy
+	proxies     map[ProxyKey]proxy
 }
 
 type proxy struct {
@@ -61,14 +63,14 @@ func (w CloseWrapper) Close() error {
 func NewPortsForwarder(s *stack.Stack) *PortsForwarder {
 	return &PortsForwarder{
 		stack:   s,
-		proxies: make(map[string]proxy),
+		proxies: make(map[ProxyKey]proxy),
 	}
 }
 
 func (f *PortsForwarder) Expose(protocol types.TransportProtocol, local, remote string) error {
 	f.proxiesLock.Lock()
 	defer f.proxiesLock.Unlock()
-	if _, ok := f.proxies[local]; ok {
+	if _, ok := f.proxies[key(protocol, local)]; ok {
 		return errors.New("proxy already running")
 	}
 
@@ -117,7 +119,7 @@ func (f *PortsForwarder) Expose(protocol types.TransportProtocol, local, remote
 			var sshForward *sshclient.SSHForward
 			var connLock sync.Mutex
 
-			dialFn = func(ctx context.Context, network, addr string) (net.Conn, error) {
+			dialFn = func(ctx context.Context, _, _ string) (net.Conn, error) {
 				connLock.Lock()
 				defer connLock.Unlock()
 
@@ -145,7 +147,7 @@ func (f *PortsForwarder) Expose(protocol types.TransportProtocol, local, remote
 				return err
 			}
 
-			dialFn = func(ctx context.Context, network, addr string) (conn net.Conn, e error) {
+			dialFn = func(ctx context.Context, _, _ string) (conn net.Conn, e error) {
 				return gonet.DialContextTCP(ctx, f.stack, address, ipv4.ProtocolNumber)
 			}
 
@@ -232,7 +234,7 @@ func (f *PortsForwarder) Expose(protocol types.TransportProtocol, local, remote
 		var p tcpproxy.Proxy
 		p.AddRoute(local, &tcpproxy.DialProxy{
 			Addr: remote,
-			DialContext: func(ctx context.Context, network, addr string) (conn net.Conn, e error) {
+			DialContext: func(ctx context.Context, _, _ string) (conn net.Conn, e error) {
 				return gonet.DialContextTCP(ctx, f.stack, address, ipv4.ProtocolNumber)
 			},
 		})
@@ -256,8 +258,8 @@ func (f *PortsForwarder) Expose(protocol types.TransportProtocol, local, remote
 	return nil
 }
 
-func key(protocol types.TransportProtocol, local string) string {
-	return fmt.Sprintf("%s/%s", protocol, local)
+func key(protocol types.TransportProtocol, local string) ProxyKey {
+	return ProxyKey(fmt.Sprintf("%s/%s", protocol, local))
 }
 
 func (f *PortsForwarder) Unexpose(protocol types.TransportProtocol, local string) error {
@@ -273,7 +275,7 @@ func (f *PortsForwarder) Unexpose(protocol types.TransportProtocol, local string
 
 func (f *PortsForwarder) Mux() http.Handler {
 	mux := http.NewServeMux()
-	mux.HandleFunc("/all", func(w http.ResponseWriter, r *http.Request) {
+	mux.HandleFunc("/all", func(w http.ResponseWriter, _ *http.Request) {
 		f.proxiesLock.Lock()
 		defer f.proxiesLock.Unlock()
 		ret := make([]proxy, 0)
@@ -376,7 +378,7 @@ func tcpipAddress(nicID tcpip.NICID, remote string) (address tcpip.FullAddress,
 		return address, errors.New("invalid remote addr")
 	}
 
-	port, err := strconv.Atoi(split[1])
+	port, err := strconv.ParseUint(split[1], 10, 16)
 	if err != nil {
 		return address, err
 
@@ -384,7 +386,7 @@ func tcpipAddress(nicID tcpip.NICID, remote string) (address tcpip.FullAddress,
 
 	address = tcpip.FullAddress{
 		NIC:  nicID,
-		Addr: tcpip.Address(net.ParseIP(split[0]).To4()),
+		Addr: tcpip.AddrFrom4Slice(net.ParseIP(split[0]).To4()),
 		Port: uint16(port),
 	}
 
